@@ -1,7 +1,7 @@
 /*******************************************************************
  * reportassistantpages_bugzilla.cpp
  * SPDX-FileCopyrightText: 2009, 2010, 2011 Dario Andres Rodriguez <andresbajotierra@gmail.com>
- * SPDX-FileCopyrightText: 2019 Harald Sitter <sitter@kde.org>
+ * SPDX-FileCopyrightText: 2019-2021 Harald Sitter <sitter@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -9,6 +9,8 @@
 
 #include "reportassistantpages_bugzilla.h"
 
+#include <chrono>
+
 #include <QAction>
 #include <QCheckBox>
 #include <QCursor>
@@ -25,6 +27,7 @@
 #include <KCapacityBar>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <kcompletion_version.h>
 #include <kwallet.h>
 
 /* Unhandled error dialog includes */
@@ -42,6 +45,8 @@
 #include "statuswidget.h"
 #include "systeminformation.h"
 
+using namespace std::chrono_literals;
+
 static const char kWalletEntryName[] = "drkonqi_bugzilla";
 static const char kWalletEntryUsername[] = "username";
 static const char kWalletEntryPassword[] = "password";
@@ -76,7 +81,11 @@ BugzillaLoginPage::BugzillaLoginPage(ReportAssistantDialog *parent)
 
     connect(ui.m_loginButton, &QPushButton::clicked, this, &BugzillaLoginPage::loginClicked);
 
+#if KCOMPLETION_VERSION >= QT_VERSION_CHECK(5, 81, 0)
+    connect(ui.m_userEdit, &KLineEdit::returnKeyPressed, this, &BugzillaLoginPage::loginClicked);
+#else
     connect(ui.m_userEdit, &KLineEdit::returnPressed, this, &BugzillaLoginPage::loginClicked);
+#endif
     connect(ui.m_passwordEdit->lineEdit(), &QLineEdit::returnPressed, this, &BugzillaLoginPage::loginClicked);
 
     connect(ui.m_userEdit, &KLineEdit::textChanged, this, &BugzillaLoginPage::updateLoginButtonStatus);
@@ -147,7 +156,7 @@ void BugzillaLoginPage::aboutToShow()
                   bugzillaManager()->getUsername()));
     } else {
         // Try to show wallet dialog once this dialog is shown
-        QTimer::singleShot(100, this, &BugzillaLoginPage::walletLogin);
+        QTimer::singleShot(100ms, this, &BugzillaLoginPage::walletLogin);
         // ...also reset focus. walletLogin may be fully no-op and not set focus
         // if it failed to do anything which leaves the focus elsewhere
         ui.m_userEdit->setFocus(Qt::OtherFocusReason);
@@ -308,7 +317,7 @@ void BugzillaLoginPage::loginFinished(bool logged)
             }
         }
 
-        emit loggedTurnToNextPage();
+        Q_EMIT loggedTurnToNextPage();
     } else {
         ui.m_statusWidget->setIdle(i18nc("@info:status", "<b>Error: Invalid e-mail address or password</b>"));
         updateWidget(true);
@@ -728,7 +737,7 @@ void BugzillaSendPage::sent(int bug_id)
                                        "You can now close this window.",
                                        reportUrl));
 
-    emit finished(false);
+    Q_EMIT finished(false);
 }
 
 void BugzillaSendPage::sendError(const QString &errorString)
