@@ -220,7 +220,7 @@ QString ReportInterface::generateReportFullText(DrKonqiStamp stamp, Backtrace in
     if (!m_possibleDuplicates.isEmpty()) {
         report.append(QLatin1Char('\n'));
         QString duplicatesString;
-        Q_FOREACH (const QString &dupe, m_possibleDuplicates) {
+        for (const QString &dupe : std::as_const(m_possibleDuplicates)) {
             duplicatesString += QLatin1String("bug ") + dupe + QLatin1String(", ");
         }
         duplicatesString = duplicatesString.left(duplicatesString.length() - 2) + QLatin1Char('.');
@@ -344,7 +344,7 @@ void ReportInterface::sendBugReport()
                 m_attachToBugNumber = bugId;
                 attachBacktrace(QStringLiteral("DrKonqi auto-attaching complete backtrace."));
             } else {
-                emit reportSent(bugId);
+                Q_EMIT reportSent(bugId);
             }
         });
         connect(m_bugzillaManager, &BugzillaManager::sendReportError, this, &ReportInterface::sendReportError);
@@ -388,7 +388,7 @@ void ReportInterface::attachSent(int attachId)
     Q_UNUSED(attachId);
 
     // The bug was attached, consider it "sent"
-    emit reportSent(m_attachToBugNumber);
+    Q_EMIT reportSent(m_attachToBugNumber);
 }
 
 QStringList ReportInterface::relatedBugzillaProducts() const
